@@ -19,7 +19,7 @@ import subprocess
 import time
 import sys
 
-from collections import namedtuple
+from collections import namedtuple, defaultdict
 from math import ceil, trunc
 
 from testutil import passed, failBecause, testing_metrics, print_table
@@ -400,6 +400,24 @@ def commit_log(commitOrRange, n=None):
         print("Expected " + str(n) + " hashes, but git gave " + str(actualN) + ":\n" + output)
     return hashes
 
+def add_new_changes(changes, new_changes):
+   for key, new_change in new_changes.items():
+       changes[key].extend(new_change)
+
+def get_allowed_changes(baseline_ref: Optional[GitRef]) -> Dict[TestName, List[AllowedPerfChange]]:
+ if baseline_ref:
+        # The last 1000 commits in reverse order (starting from HEAD).
+        commit_hashes = baseline_commit_log(GitRef("HEAD"))
+        allowed_changes = defaultdict(list) # type: Dict[TestName, List[AllowedPerfChange]]
+        for commit in commit_hashes:
+            new_changes = get_allowed_perf_changes(commit)
+            if commit == baseline_ref: return dict(allowed_changes)
+            add_new_changes(allowed_changes, new_changes)
+        print("PERF_BASELINE_COMMIT not found in last 1000 commits...")
+        return dict()
+ else:
+        return get_allowed_perf_changes()
+
 # Cache of baseline values. This is a dict of dicts indexed on:
 # (useCiNamespace, commit) -> (test_env, test, metric, way) -> baseline
 # (bool          , str   ) -> (str     , str , str   , str) -> float
@@ -432,9 +450,9 @@ def baseline_metric(commit: GitHash,
     assert is_commit_hash(commit)
 
     # Get all recent commit hashes.
-    commit_hashes = baseline_commit_log(commit)
+    commit_hashes = baseline_commit_log(commit_hash(baseline_ref) if baseline_ref else commit)
 
-    baseline_commit = commit_hash(baseline_ref) if baseline_ref else None
+    baseline_commit = None
 
     def has_expected_change(commit: GitHash) -> bool:
         return get_allowed_perf_changes(commit).get(name) is not None
@@ -450,7 +468,8 @@ def baseline_metric(commit: GitHash,
             else:
                 return None
 
-        for depth, current_commit in list(enumerate(commit_hashes))[1:]:
+        for depth, current_commit in list(enumerate(commit_hashes)):
+            if current_commit == commit: continue
             # Check for a metric on this commit.
             current_metric = get_commit_metric(namespace, current_commit, test_env, name, metric, way)
             if current_metric is not None:
@@ -797,7 +816,7 @@ def main() -> None:
     # HEAD~3           20000                 20000
     def strMetric(x):
         return '{:.2f}'.format(x.value) if x != None else ""
-    # Data is in colum major format, so transpose and pass to print_table.
+    # Data is in column major format, so transpose and pass to print_table.
     T = TypeVar('T')
     def transpose(xss: List[List[T]]) -> List[List[T]]:
         return list(map(list, zip(*xss)))
