@@ -1,3 +1,4 @@
+{-# LANGUAGE Haskell2010 #-}
 {- This is the code extracted from "A reflection on types", by Simon PJ,
 Stephanie Weirich, Richard Eisenberg, and Dimitrios Vytiniotis, 2016. -}
 
@@ -128,7 +129,7 @@ gcast x = do  Refl <- eqT  (typeRep :: TypeRep a)
               return x
 
 data SameKind :: k -> k -> Type
-type CheckAppResult = SameKind AppResult AppResultNoKind
+
   --  not the most thorough check
 foo :: AppResult x -> AppResultNoKind x
 foo (App y z) = AppNoKind y z
