@@ -1,14 +1,10 @@
 {-# Language PolyKinds          #-}
 {-# Language TypeApplications   #-}
-{-# Language ImpredicativeTypes #-}
 {-# Language LiberalTypeSynonyms #-}
 
 module T15859 where
 
 import Data.Kind
 
-data A k :: k -> Type
+a = (undefined :: forall k -> k -> Type) @Int
 
-type KindOf (a :: k) = k
-
-a = (undefined :: KindOf A) @Int
