@@ -6,8 +6,8 @@ module T12512 where
 
 import GHC.Exts
 
-class Wat1 (a :: TYPE ('TupleRep ['LiftedRep, 'LiftedRep]))
+class Wat1 (a :: TYPE ('TupleRep ['BoxedRep 'Lifted, 'BoxedRep 'Lifted]))
 deriving instance Wat1 (# a, b #)
 
-class Wat2 (a :: TYPE ('SumRep ['LiftedRep, 'LiftedRep]))
+class Wat2 (a :: TYPE ('SumRep ['BoxedRep 'Lifted, 'BoxedRep 'Lifted]))
 deriving instance Wat2 (# a | b #)
