@@ -5,12 +5,14 @@
 import GHC
 import GHC.Driver.Make
 import GHC.Driver.Session
-import GHC.Unit.Module.ModSummary (ExtendedModSummary(..))
+import GHC.Driver.Env
+import GHC.Unit.Module.Graph
 import GHC.Unit.Finder
 
 import Control.Monad.IO.Class (liftIO)
 import Data.List (sort, stripPrefix)
 import Data.Either
+import Data.Maybe
 
 import System.Environment
 import System.Directory
@@ -39,7 +41,7 @@ main = do
         ]
       ]
 
-    tgt <- guessTarget "A" Nothing
+    tgt <- guessTarget "A" Nothing Nothing
     setTargets [tgt]
     hsc_env <- getSession
 
@@ -47,18 +49,18 @@ main = do
 
     _emss <- downsweep hsc_env [] [] False
 
-    flushFinderCaches hsc_env
+    flushFinderCaches (hsc_FC hsc_env) (hsc_unit_env hsc_env)
     createDirectoryIfMissing False "mydir"
     renameFile "B.hs" "mydir/B.hs"
 
-    emss <- downsweep hsc_env [] [] False
+    (_, nodes) <- downsweep hsc_env [] [] False
 
     -- If 'checkSummaryTimestamp' were to call 'addHomeModuleToFinder' with
     -- (ms_location old_summary) like summariseFile used to instead of
     -- using the 'location' parameter we'd end up using the old location of
     -- the "B" module in this test. Make sure that doesn't happen.
 
-    hPrint stderr $ sort (map (ml_hs_file . ms_location) (map emsModSummary (rights emss)))
+    hPrint stderr $ sort (map (ml_hs_file . ms_location) (mapMaybe moduleGraphNodeModSum nodes))
 
 writeMod :: [String] -> IO ()
 writeMod src@(head -> stripPrefix "module " -> Just (takeWhile (/=' ') -> mod))
