@@ -2,7 +2,7 @@ module DumpSemis where
 
 -- Make sure we get all the semicolons in statements
 ;;;;  ;;
-import Data.Maybe
+import Data.List ()
 ; ; ;
 import Data.Kind
    ; ;;
