@@ -3,4 +3,4 @@
 module T15323 where
 
 data MaybeDefault v where
-    TestParens  :: (forall v . (Eq v) => MaybeDefault v)
+    TestParens  :: forall v . (Eq v) => MaybeDefault v
