@@ -1,4 +1,4 @@
-{-# LANGUAGE MagicHash #-}
+{-# LANGUAGE MagicHash, ExtendedLiterals #-}
 
 module Main where
 
@@ -13,17 +13,24 @@ data Test2 = Test2 Int16# Word16#
 data Test3 = Test3 Int32# Word32#
     deriving (Show)
 
+data Test4 = Test4 Int64# Word64#
+    deriving (Show)
+
 test1 :: Test1
-test1 = Test1 (intToInt8# 1#) (wordToWord8# 2##)
+test1 = Test1 1#Int8 2#Word8
 
 test2 :: Test2
-test2 = Test2 (intToInt16# 1#) (wordToWord16# 2##)
+test2 = Test2 1#Int16 2#Word16
 
 test3 :: Test3
-test3 = Test3 (intToInt32# 1#) (wordToWord32# 2##)
+test3 = Test3 1#Int32 2#Word32
+
+test4 :: Test4
+test4 = Test4 -9223372036854775808#Int64 18446744073709551610#Word64
 
 main :: IO ()
 main = do
   print test1
   print test2
   print test3
+  print test4
