@@ -6,4 +6,4 @@ module SAKS_018 where
 import Data.Kind (Type)
 
 type T :: forall k -> k -> Type
-data T k (x :: hk)
+data T j (x :: j)
