@@ -5,5 +5,5 @@ module SAKS_Fail009 where
 
 import Data.Kind (Type)
 
-type T :: forall k -> k -> Type
+type T :: forall j -> j -> Type
 data T (k :: Type -> Type) (a :: k)
