@@ -4,7 +4,7 @@ module TH_Roles2 where
 
 import Language.Haskell.TH
 
-$( return [ DataD [] (mkName "T") [KindedTV (mkName "a") () (VarT (mkName "k"))]
+$( return [ DataD [] (mkName "T") [KindedTV (mkName "a") BndrReq (VarT (mkName "k"))]
             Nothing [] []
           , RoleAnnotD (mkName "T") [RepresentationalR] ] )
 
