@@ -5,3 +5,6 @@ f = _
 
 g :: [Integer] -> Integer
 g = _ 0
+
+j :: a -> a
+j a = _
